@@ -187,8 +187,19 @@ fn codegen_registry() {
                     .collect::<Vec<_>>()
             })
             .unwrap_or_default();
+        let overrides = info
+            .get("overrides")
+            .map(|overrides| {
+                overrides
+                    .as_array()
+                    .unwrap()
+                    .iter()
+                    .map(|f| f.as_str().unwrap().to_string())
+                    .collect::<Vec<_>>()
+            })
+            .unwrap_or_default();
         let rt = format!(
-            r#"RegistryTool{{short: "{short}", description: {description}, backends: &[{backends}], aliases: &[{aliases}], test: &{test}, os: &[{os}], depends: &[{depends}], idiomatic_files: &[{idiomatic_files}]}}"#,
+            r#"RegistryTool{{short: "{short}", description: {description}, backends: &[{backends}], aliases: &[{aliases}], test: &{test}, os: &[{os}], depends: &[{depends}], idiomatic_files: &[{idiomatic_files}], overrides: &[{overrides}]}}"#,
             description = description
                 .map(|d| format!("Some({})", raw_string_literal(&d)))
                 .unwrap_or("None".to_string()),
@@ -220,6 +231,11 @@ fn codegen_registry() {
                 .map(|f| format!("\"{f}\""))
                 .collect::<Vec<_>>()
                 .join(", "),
+            overrides = overrides
+                .iter()
+                .map(|f| format!("\"{f}\""))
+                .collect::<Vec<_>>()
+                .join(", "),
         );
         lines.push(format!(r#"    ("{short}", {rt}),"#));
         for alias in aliases {
@@ -398,5 +414,51 @@ pub static SETTINGS_META: Lazy<IndexMap<&'static str, SettingsMeta>> = Lazy::new
         .to_string(),
     );
 
+    // Generate MisercSettings struct for early initialization settings
+    lines.push(
+        r#"
+/// Settings that can be set in .miserc.toml for early initialization.
+/// These settings affect config file discovery and must be loaded before
+/// the main config files are parsed.
+#[derive(Debug, Clone, Default, serde::Deserialize)]
+pub struct MisercSettings {"#
+            .to_string(),
+    );
+
+    for (key, props) in &settings {
+        let props = props.as_table().unwrap();
+        // Only include settings with rc = true
+        if props
+            .get("rc")
+            .is_some_and(|v| v.as_bool().unwrap_or(false))
+        {
+            if let Some(description) = props.get("description") {
+                lines.push(format!("    /// {}", description.as_str().unwrap()));
+            }
+            let type_ = props
+                .get("rust_type")
+                .map(|rt| rt.as_str().unwrap())
+                .or(props.get("type").map(|t| match t.as_str().unwrap() {
+                    "Bool" => "bool",
+                    "String" => "String",
+                    "Integer" => "i64",
+                    "Url" => "String",
+                    "Path" => "PathBuf",
+                    "Duration" => "String",
+                    "ListString" => "Vec<String>",
+                    "ListPath" => "Vec<PathBuf>",
+                    "SetString" => "BTreeSet<String>",
+                    "IndexMap<String, String>" => "IndexMap<String, String>",
+                    t => panic!("Unknown type: {t}"),
+                }));
+            if let Some(type_) = type_ {
+                // All miserc settings are optional
+                let type_ = format!("Option<{type_}>");
+                lines.push(format!("    pub {key}: {type_},"));
+            }
+        }
+    }
+    lines.push("}".to_string());
+
     fs::write(&dest_path, lines.join("\n")).unwrap();
 }
