@@ -23,11 +23,17 @@ static AFTER_LONG_HELP: &str = color_print::cstr!(
     r#"<bold><underline>Examples:</underline></bold>
 
     $ <bold>mise backends ls</bold>
+    aqua
+    asdf
     cargo
+    core
+    dotnet
+    gem
     go
     npm
     pipx
     spm
     ubi
+    vfox
 "#
 );
